package gateway
import "github.com/grpc-ecosystem/grpc-gateway/v2/examples/internal/gateway"
Package gateway is an example of gRPC-Gateway server
Index ¶
Functions ¶
func Run ¶
Run starts a HTTP server and blocks while running if successful. The server will be shutdown when "ctx" is canceled.
Types ¶
type Endpoint ¶
type Endpoint struct {
Network, Addr string
}
Endpoint describes a gRPC endpoint
type Options ¶
type Options struct {
// Addr is the address to listen
Addr string
// GRPCServer defines an endpoint of a gRPC service
GRPCServer Endpoint
// OpenAPIDir is a path to a directory from which the server
// serves OpenAPI specs.
OpenAPIDir string
// Mux is a list of options to be passed to the gRPC-Gateway multiplexer
Mux []gwruntime.ServeMuxOption
}
Options is a set of options to be passed to Run
Source Files ¶
doc.go gateway.go handlers.go main.go
- Version
- v2.27.1 (latest)
- Published
- Jun 24, 2025
- Platform
- linux/amd64
- Imports
- 17 packages
- Last checked
- 8 months ago –
Tools for package owners.