package httprule
import "github.com/grpc-ecosystem/grpc-gateway/v2/internal/httprule"
Index ¶
Types ¶
type Compiler ¶
type Compiler interface {
Compile() Template
}
Compiler compiles utilities representation of path templates into marshallable operations. They can be unmarshalled by runtime.NewPattern.
func Parse ¶
Parse parses the string representation of path template
type InvalidTemplateError ¶
type InvalidTemplateError struct {
// contains filtered or unexported fields
}
InvalidTemplateError indicates that the path template is not valid.
func (InvalidTemplateError) Error ¶
func (e InvalidTemplateError) Error() string
type Template ¶
type Template struct {
// Version is the version number of the format.
Version int
// OpCodes is a sequence of operations.
OpCodes []int
// Pool is a constant pool
Pool []string
// Verb is a VERB part in the template.
Verb string
// Fields is a list of field paths bound in this template.
Fields []string
// Original template (example: /v1/a_bit_of_everything)
Template string
}
Template is a compiled representation of path templates.
Source Files ¶
- Version
- v2.27.1 (latest)
- Published
- Jun 24, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 8 months ago –
Tools for package owners.